import os
import sys
import MySQLdb
from CFDB_Classes import *

class CFDB_Database():
	host = "127.0.0.1"
	user = "ncaa_football"
	passwd = "f00Tb4llP00!"
	db = "NCAA_Football_2024"
	
	def __init__(self):
		self.conn = MySQLdb.connect (self.host, self.user, self.passwd, self.db)
		self.cursor = self.conn.cursor()

	def ClearTable(self, tableName):
		cypher = "DROP TABLE IF EXISTS {0}".format(tableName)

		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def ClearTables(self):
		cypher = "DROP TABLE IF EXISTS Games,Teams,Calendar,Records,Conferences,Venues,Rankings,Scoreboard"

		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1


	def InitializeDatabase(self):
		if self.ClearTables():
			return -1

		print("Initializing databases...", flush=True, end='')
		try:
			if self.CreateGamesTable():
				return -1
			if self.CreateTeamsTable():
				return -1
			if self.CreateCalendarTable():
				return -1
			if self.CreateRecordsTable():
				return -1
			if self.CreateConferencesTable():
				return -1
			if self.CreateVenuesTable():
				return -1
			if self.CreateRankingsTable():
				return -1
			if self.CreateScoreboardTable():
				return -1
			print("done", flush=True)
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def CreateGamesTable(self):
		cypher = 'CREATE TABLE Games({0})'.format('''
			id INT PRIMARY KEY NOT NULL, 
			season SMALLINT,
			week TINYINT, 
			season_type CHAR(64), 
			start_date CHAR(64), 
			start_time_tbd BOOLEAN, 
			completed BOOLEAN, 
			neutral_site BOOLEAN, 
			conference_game BOOLEAN, 
			attendance INT, 
			venue_id INT, 
			home_id INT, 
			home_team CHAR(128), 
			home_conference CHAR(128), 
			home_division CHAR(128), 
			home_points TINYINT, 
			home_points_q1 TINYINT, 
			home_points_q2 TINYINT, 
			home_points_q3 TINYINT, 
			home_points_q4 TINYINT, 
			home_points_ot TINYINT, 
			home_post_win_prob DECIMAL(5,2), 
			home_pregame_elo SMALLINT, 
			home_postgame_elo SMALLINT, 
			away_id INT, 
			away_team CHAR(128), 
			away_conference CHAR(128), 
			away_division CHAR(128), 
			away_points TINYINT, 
			away_points_q1 TINYINT, 
			away_points_q2 TINYINT, 
			away_points_q3 TINYINT, 
			away_points_q4 TINYINT, 
			away_points_ot TINYINT, 
			away_post_win_prob DECIMAL(5,2), 
			away_pregame_elo SMALLINT, 
			away_postgame_elo SMALLINT, 
			excitement_index DECIMAL(5,2), 
			highlights VARCHAR(1024), 
			notes VARCHAR(1024)'''
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def CreateTeamsTable(self):
		cypher = 'CREATE TABLE Teams({0})'.format('''
			id INT PRIMARY KEY NOT NULL, 
			school CHAR(128), 
			mascot CHAR(64), 
			abbreviation CHAR(10), 
			alt_name_1 CHAR(128), 
			alt_name_2 CHAR(128), 
			alt_name_3 CHAR(128), 
			classification CHAR(128), 
			conference CHAR(128), 
			division CHAR(128), 
			color CHAR(32), 
			alt_color CHAR(32), 
			logo CHAR(255), 
			twitter CHAR(255), 
			locationId INT, 
			locationName CHAR(128), 
			locationCapacity INT, 
			locationGrass BOOLEAN, 
			locationCity CHAR(64), 
			locationState CHAR(64), 
			locationZip CHAR(16), 
			locationCountryCode CHAR(64), 
			locationX DECIMAL(5,2), 
			locationY DECIMAL(5,2), 
			locationElevation SMALLINT, 
			locationYearConstructed SMALLINT, 
			locationDome BOOLEAN, 
			locationTimezone CHAR (32)'''
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def CreateCalendarTable(self):
		cypher = 'CREATE TABLE Calendar({0})'.format('''
			season SMALLINT,
			week TINYINT,
			seasonType CHAR(64),
			firstGameStart CHAR(128),
			lastGameStart CHAR(128)'''
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def CreateRecordsTable(self):
		cypher = 'CREATE TABLE Records({0})'.format('''
			year SMALLINT,
			team CHAR(128),
			conference CHAR(128),
			division CHAR(128),
			expectedWins TINYINT,
			totalGames TINYINT,
			totalWins TINYINT,
			totalLosses TINYINT,
			totalTies TINYINT,
			conferenceGames TINYINT,
			conferenceWins TINYINT,
			conferenceLosses TINYINT,
			conferenceTies TINYINT,
			homeGames TINYINT,
			homeWins TINYINT,
			homeLosses TINYINT,
			homeTies TINYINT,
			awayGames TINYINT,
			awayWins TINYINT,
			awayLosses TINYINT,
			awayTies TINYINT'''
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def CreateConferencesTable(self):
		cypher = 'CREATE TABLE Conferences({0})'.format('''
			id INT PRIMARY KEY NOT NULL, 
			name CHAR(128), 
			short_name CHAR(32), 
			abbreviation CHAR(10), 
			classification CHAR(128)'''
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def CreateVenuesTable(self):
		cypher = 'CREATE TABLE Venues({0})'.format('''
			id INT PRIMARY KEY NOT NULL,
			name CHAR(128),
			capacity INT,
			grass BOOLEAN,
			city CHAR(64), 
			state CHAR(64), 
			zip CHAR(16), 
			countryCode CHAR(64), 
			x DECIMAL(5,2), 
			y DECIMAL(5,2), 
			elevation SMALLINT, 
			yearConstructed SMALLINT, 
			dome BOOLEAN, 
			timezone CHAR (32)''' 
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1
			
	def CreateRankingsTable(self):
		cypher = 'CREATE TABLE Rankings({0})'.format('''
			season SMALLINT,
			seasonType CHAR(64),
			week TINYINT,
			pollName CHAR(64),
			teamRank TINYINT,
			school CHAR(128),
			conference CHAR(128),
			firstPlaceVotes SMALLINT,
			points SMALLINT'''
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def CreateScoreboardTable(self):
		cypher = 'CREATE TABLE Scoreboard({0})'.format('''
			id INT NOT NULL PRIMARY KEY,
			startDate CHAR(64),
			startTimeTBD BOOLEAN,
			tv CHAR(64),
			neutralSite BOOLEAN,
			conferenceGame BOOLEAN,
			status CHAR(128),
			period INT,
			clock CHAR(64),
			situation CHAR(128),
			possession CHAR(128),
			venueName CHAR(128),
			venueCity CHAR(64),
			venueState CHAR(64),
			homeId INT,
			homeName CHAR(64),
			homeConference CHAR(64),
			homeClassification CHAR(64),
			homePoints INT,
			awayId INT,
			awayName CHAR(64),
			awayConference CHAR(64),
			awayClassification CHAR(64),
			awayPoints INT,
			temperature DECIMAL(6,2),
			weatherDescription CHAR(64),
			windSpeed DECIMAL(6,2),
			windDirection DECIMAL(6,2),
			spread DECIMAL(6,2),
			overUnder DECIMAL(6,2),
			homeMoneyLine INT,
			awayMoneyLine INT'''
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1
			
	def AddNewTeam(self, team):
		cypher = '''INSERT INTO Teams (id, school, mascot, abbreviation, alt_name_1, alt_name_2, alt_name_3,
					classification, conference, division, color, alt_color, logo, twitter, locationId, 
					locationName, locationCapacity, locationGrass, locationCity, locationState, locationZip,
					locationCountryCode, locationX, locationY, locationElevation, locationYearConstructed,
					locationDome, locationTimezone) VALUES({0},"{1}","{2}","{3}","{4}","{5}","{6}","{7}","{8}","{9}","{10}","{11}","{12}","{13}",{14},"{15}",{16},{17},"{18}","{19}","{20}","{21}",{22},{23},{24},{25},{26},"{27}")'''.format(
					team.id,
					team.school,
					team.mascot,
					team.abbreviation,
					team.alt_name_1,
					team.alt_name_2,
					team.alt_name_3,
					team.classification,
					team.conference,
					team.division,
					team.color,
					team.alt_color,
					team.logo[0],
					team.twitter,
					team.location.id,
					team.location.name.replace('"',"'"),
					team.location.capacity,
					team.location.grass,
					team.location.city,
					team.location.state,
					team.location.zip,
					team.location.country_code,
					team.location.location["x"],
					team.location.location["y"],
					team.location.elevation,
					team.location.year_constructed,
					team.location.dome,
					team.location.timezone
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print(cypher)
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def UpdateTeams(self, teams, databaseTeams):
		for teamID in teams:
			try:
				currentTeam = teams[teamID]
				if currentTeam != databaseTeams[teamID]:
					currentTeam = databaseTeams[teamID]
					currentTeam.Update(teams[teamID])
					cypher = 'UPDATE Teams SET Name="{0}",DisplayName="{1}",Abbreviation="{2}",ShortDisplayName="{3}",PrimaryColor="{4}",' \
									'AlternateColor="{5}",Conference={6},Division={7},TotalWins={8},TotalLosses={9},TotalTies={10},HomeWins={11},' \
									'HomeLosses={12},HomeTies={13},AwayWins={14},AwayLosses={15},AwayTies={16},ConfWins={17},' \
									'ConfLosses={18},ConfTies={19},URL="{20}",IconURL="{21}" WHERE TeamID={22}'.format(
									currentTeam.name,
									currentTeam.displayName,
									currentTeam.abbreviation,
									currentTeam.shortDisplayName,
									currentTeam.primaryColor,
									currentTeam.alternateColor,
									currentTeam.conference,
									currentTeam.division,
									currentTeam.totalWins,
									currentTeam.totalLosses,
									currentTeam.totalTies,
									currentTeam.homeWins,
									currentTeam.homeLosses,
									currentTeam.homeTies,
									currentTeam.awayWins,
									currentTeam.awayLosses,
									currentTeam.awayTies,
									currentTeam.confWins,
									currentTeam.confLosses,
									currentTeam.confTies,
									currentTeam.url,
									currentTeam.icon,
									currentTeam.id)
					self.cursor.execute(cypher)
					self.conn.commit()
			except KeyError:
				self.AddNewTeam(teams[teamID])
			except MySQLdb.Error as e:
				print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
				return -1
		return 0

	def AddNewGame(self, game):
		cypher = '''INSERT INTO Games (id, season, week, season_type, start_date, start_time_tbd, completed, neutral_site, conference_game,
									attendance, venue_id, home_id, home_team, home_conference, home_division, home_points,
									home_points_q1, home_points_q2, home_points_q3, home_points_q4, home_points_ot,
									home_post_win_prob, home_pregame_elo, home_postgame_elo, away_id, away_team, away_conference,
									away_division, away_points, away_points_q1, away_points_q2, away_points_q3, away_points_q4, 
									away_points_ot, away_post_win_prob, away_pregame_elo, away_postgame_elo, excitement_index,
									highlights, notes) 
									VALUES({0},{1},{2},"{3}","{4}",{5},{6},{7},{8},{9},{10},{11},"{12}","{13}","{14}",{15},{16},{17},{18},{19},{20},{21},{22},{23},{24},"{25}","{26}","{27}",{28},{29},{30},{31},{32},{33},{34},{35},{36},{37},"{38}","{39}")'''.format(
			game.id,
			game.season,
			game.week,
			game.season_type,
			game.start_date,
			game.start_time_tbd,
			game.completed,
			game.neutral_site,
			game.conference_game,
			game.attendance,
			game.venue_id,
			game.home_id,
			game.home_team,
			game.home_conference,
			game.home_division,
			game.home_points,
			game.home_points_q1,
			game.home_points_q2,
			game.home_points_q3,
			game.home_points_q4,
			game.home_points_ot,
			game.home_post_win_prob,
			game.home_pregame_elo,
			game.home_postgame_elo,
			game.away_id,
			game.away_team,
			game.away_conference,
			game.away_division,
			game.away_points,
			game.away_points_q1,
			game.away_points_q2,
			game.away_points_q3,
			game.away_points_q4,
			game.away_points_ot,
			game.away_post_win_prob,
			game.away_pregame_elo,
			game.away_postgame_elo,	
			game.excitement_index,
			game.highlights,
			game.notes
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print(cypher)
			print("Error in {0}: {1}".format(sys._getframe().f_code.co_name, e))
			return -1

	def UpdateGameData(self, game):
		cypher = '''UPDATE Games SET completed={0},attendance={1},venue_id={2},home_points={3},home_points_q1={4},
					home_points_q2={5},home_points_q3={6},home_points_q4={7},home_points_ot={8},away_points={9},
					away_points_q1={10},away_points_q2={11},away_points_q3={12},away_points_q4={13},away_points_ot={14},
					excitement_index={15},highlights="{16}",notes="{17}" WHERE id={18}'''.format(
			game.completed,
			game.attendance,
			game.venue_id,
			game.home_points,
			game.home_points_q1,
			game.home_points_q2,
			game.home_points_q3,
			game.home_points_q4,
			game.home_points_ot,
			game.away_points,
			game.away_points_q1,
			game.away_points_q2,
			game.away_points_q3,
			game.away_points_q4,
			game.away_points_ot,
			game.excitement_index,
			game.highlights,
			game.notes,
			game.id
			)
		try:
			#if game.week == 1:
			#	print(cypher)
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except KeyError:
				# here we create the game because it is not in the database
				return self.AddNewGame(currentGame)
		except MySQLdb.Error as e:
			print(cypher)
			print("Error in {0}: {1}".format(sys._getframe().f_code.co_name, e))
			return -1
	
	def ClearScoreboard(self):
		cypher = "DELETE FROM Scoreboard"

		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print(cypher)
			print("Error in {0}: {1}".format(sys._getframe().f_code.co_name, e))
			return -1

	def UpdateScoreboardGame(self, game):
		cypher = '''INSERT INTO Scoreboard (id, startDate, startTimeTBD, tv, 
						neutralSite, conferenceGame, status, period, clock, situation, 
						possession, venueName, venueCity, venueState, homeId, homeName,
						homeConference, homeClassification, homePoints, awayId, awayName,
						awayConference, awayClassification, awayPoints, temperature, 
						weatherDescription, windSpeed, windDirection, spread, overunder,
						homeMoneyLine, awayMoneyLine) VALUES ({0},"{1}",{2},"{3}",{4},{5},"{6}",{7},"{8}","{9}","{10}","{11}","{12}","{13}",{14},"{15}","{16}","{17}",{18},{19},"{20}","{21}","{22}",{23},{24},"{25}",{26},{27},{28},{29},{30},{31})'''.format(
			game.id,
			game.startDate,
			game.startTimeTBD,
			game.tv,
			game.neutralSite,
			game.conferenceGame,
			game.status,
			game.period,
			game.clock,
			game.situation,
			game.possession,
			game.venue.name,
			game.venue.city,
			game.venue.state,
			game.homeTeam.id,
			game.homeTeam.name,
			game.homeTeam.conference,
			game.homeTeam.classification,
			game.homeTeam.points,
			game.awayTeam.id,
			game.awayTeam.name,
			game.awayTeam.conference,
			game.awayTeam.classification,
			game.awayTeam.points,
			game.weather.temperature,
			game.weather.description,
			game.weather.windSpeed,
			game.weather.windDirection,
			game.betting.spread,
			game.betting.overUnder,
			game.betting.homeMoneyLine,
			game.betting.awayMoneyLine
			)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print(cypher)
			print("Error in {0}: {1}".format(sys._getframe().f_code.co_name, e))
			return -1

	def AddCalendarWeek(self, week):
		cypher = '''INSERT INTO Calendar (season, week, seasonType, firstGameStart, lastGameStart) 
					VALUES({0},{1},"{2}","{3}","{4}")'''.format(
				week.season,
				week.week,
				week.seasonType,
				week.firstGameStart,
				week.lastGameStart
				)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1
					
	def AddRecord(self, record):
		cypher = '''INSERT INTO Records (year, team, conference, division, expectedWins, totalGames,
					totalWins, totalLosses, totalTies, conferenceGames, conferenceWins, conferenceLosses,
					conferenceTies, homeGames, homeWins, homeLosses, homeTies, awayGames, awayWins, 
					awayLosses, awayTies) VALUES ({0},"{1}","{2}","{3}",{4},{5},{6},{7},{8},{9},{10},
					{11},{12},{13},{14},{15},{16},{17},{18},{19},{20})'''.format(
					record.year,
					record.team,
					record.conference,
					record.division,
					record.expectedWins,
					record.total.games,
					record.total.wins,
					record.total.losses,
					record.total.ties,
					record.conferenceGames.games,
					record.conferenceGames.wins,
					record.conferenceGames.losses,
					record.conferenceGames.ties,
					record.homeGames.games,
					record.homeGames.wins,
					record.homeGames.losses,
					record.homeGames.ties,
					record.awayGames.games,
					record.awayGames.wins,
					record.awayGames.losses,
					record.awayGames.ties
					)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def UpdateRecordData(self, record):
		cypher = '''UPDATE Records SET expectedWins={0},totalGames={1},totalWins={2},totalLosses={3},totalTies={4},
					conferenceGames={5},conferenceWins={6},conferenceLosses={7},conferenceTies={8},homeGames={9},
					homeWins={10},homeLosses={11},homeTies={12},awayGames={13},awayWins={14},awayLosses={15},
					awayTies={16} WHERE year={17} AND team="{18}"'''.format(
					record.expectedWins,
					record.total.games,
					record.total.wins,
					record.total.losses,
					record.total.ties,
					record.conferenceGames.games,
					record.conferenceGames.wins,
					record.conferenceGames.losses,
					record.conferenceGames.ties,
					record.homeGames.games,
					record.homeGames.wins,
					record.homeGames.losses,
					record.homeGames.ties,
					record.awayGames.games,
					record.awayGames.wins,
					record.awayGames.losses,
					record.awayGames.ties,
					record.year,
					record.team
					)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print(cypher, flush=True)
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1
	
	def AddConference(self, conference):
		cypher = '''INSERT INTO Conferences (id, name, short_name, abbreviation, classification) 
					VALUES ({0},"{1}","{2}","{3}","{4}")'''.format(
					conference.id,
					conference.name,
					conference.short_name,
					conference.abbreviation,
					conference.classification
					)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def AddVenue(self, venue):
		cypher = '''INSERT INTO Venues (id, name, capacity, grass, city, state, zip, countryCode,
					x, y, elevation, yearConstructed, dome, timezone) VALUE ({0},"{1}",{2},{3},"{4}",
					"{5}","{6}","{7}",{8},{9},{10},{11},{12},"{13}")'''.format(
					venue.id,
					venue.name.replace('"',"'"),
					venue.capacity,
					venue.grass,
					venue.city,
					venue.state,
					venue.zip,
					venue.country_code,
					venue.location["x"],
					venue.location["y"],
					venue.elevation,
					venue.year_constructed,
					venue.dome,
					venue.timezone
					)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print(cypher)
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def AddRanking(self, season, seasonType, week, pollName, ranking):
		cypher = '''INSERT INTO Rankings (season, seasonType, week, pollName, teamRank, school, conference,
					firstPlaceVotes, points) VALUES ({0},"{1}",{2},"{3}",{4},"{5}","{6}",{7},{8})'''.format(
					season,
					seasonType,
					week,
					pollName,
					ranking.rank,
					ranking.school,
					ranking.conference,
					ranking.firstPlaceVotes,
					ranking.points
					)
		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def ClearRankings(self):
		cypher = "DELETE FROM Rankings"

		try:
			self.cursor.execute(cypher)
			self.conn.commit()
			return 0
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1
	
	def GetCurrentWeek(self):
		cypher = 'SELECT MAX(week) FROM Games WHERE id IN (SELECT id FROM Scoreboard)'

		try:
			self.cursor.execute(cypher)
			currentWeek = int(self.cursor.fetchone()[0])
			return currentWeek
		except MySQLdb.Error as e:
			print(cypher)
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def GetCurrentSeason(self):
		cypher = 'SELECT DISTINCT(season_type) FROM Games WHERE id IN (SELECT id FROM Scoreboard)'

		try:
			self.cursor.execute(cypher)
			currentSeason = self.cursor.fetchone()[0]
			return currentSeason
		except MySQLdb.Error as e:
			print(cypher)
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def GetNumberOfWeeksInSeason(self):
		cypher = 'SELECT MAX(week) FROM Calendar WHERE seasonType="regular"'

		try:
			self.cursor.execute(cypher)
			lastWeek = int(self.cursor.fetchone()[0])
			return lastWeek
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return -1

	def GetScoreboardGames(self):
		cypher = 'SELECT * From Scoreboard'
		gameArray = []

		try:
			self.cursor.execute( cypher )
			scoreboardData = self.cursor.fetchall()
			for scoreboardGame in scoreboardData:
				gameString = '{0}'.format( scoreboardGame )
				gameString = gameString.lstrip( "(" )
				gameString = gameString.rstrip( ")" )
				gameData = gameString.split( "," )
				newGame = CFDB_ScoreboardGame()
				newGame.id = int( gameData[0] )
				gameData[1] = gameData[1].rstrip(" '\"")
				newGame.startDate = gameData[1].lstrip(" '\"")
				if int(gameData[2]) != 0:
					newGame.startTimeTBD = True
				newGame.tv = gameData[3]
				if int(gameData[4]) != 0:
					newGame.neutralSite = True
				if int(gameData[5]) != 0:
					newGame.conferenceGame = True
				gameData[6] = gameData[6].rstrip(" '\"")
				newGame.status = gameData[6].lstrip(" '\"")
				newGame.period = int(gameData[7])
				gameData[8] = gameData[8].rstrip(" '\"")
				newGame.clock = gameData[8].lstrip(" '\"")
				gameData[9] = gameData[9].rstrip(" '\"")
				newGame.situation = gameData[9].lstrip(" '\"")
				gameData[10] = gameData[10].rstrip(" '\"")
				newGame.possession = gameData[10].lstrip(" '\"")
				gameData[11] = gameData[11].rstrip(" '\"")
				newGame.venue.name = gameData[11].lstrip(" '\"")
				gameData[12] = gameData[12].rstrip(" '\"")
				newGame.venue.city = gameData[12].lstrip(" '\"")
				gameData[13] = gameData[13].rstrip(" '\"")
				newGame.venue.state = gameData[13].lstrip(" '\"")
				newGame.homeTeam.id = int( gameData[14] )
				gameData[15] = gameData[15].rstrip(" '\"")
				newGame.homeTeam.name = gameData[15].lstrip(" '\"")
				gameData[16] = gameData[16].rstrip(" '\"")
				newGame.homeTeam.conference = gameData[16].lstrip(" '\"")
				gameData[17] = gameData[17].rstrip(" '\"")
				newGame.homeTeam.classification = gameData[17].lstrip(" '\"")
				newGame.homeTeam.points = int( gameData[18] )
				newGame.awayTeam.id = int( gameData[19] )
				gameData[20] = gameData[20].rstrip(" '\"")
				newGame.awayTeam.name = gameData[20].lstrip(" '\"")
				gameData[21] = gameData[21].rstrip(" '\"")
				newGame.awayTeam.conference = gameData[21].lstrip(" '\"")
				gameData[22] = gameData[22].rstrip(" '\"")
				newGame.awayTeam.classification = gameData[22].lstrip(" '\"")
				newGame.awayTeam.points = int( gameData[23] )
				gameData[24] = gameData[24][gameData[24].find('(')+1:gameData[24].find(')')]
				gameData[24] = gameData[24].replace("'", '')
				newGame.weather.temperature = float( gameData[24] )
				gameData[25] = gameData[25].rstrip(" '\"")
				newGame.weather.description = gameData[25]
				gameData[26] = gameData[26][gameData[26].find('(')+1:gameData[26].find(')')]
				gameData[26] = gameData[26].replace("'", '')
				newGame.weather.windSpeed = float( gameData[26] )
				gameData[27] = gameData[27][gameData[27].find('(')+1:gameData[27].find(')')]
				gameData[27] = gameData[27].replace("'", '')
				newGame.weather.windDirection = float( gameData[27] )
				gameData[28] = gameData[28][gameData[28].find('(')+1:gameData[28].find(')')]
				gameData[28] = gameData[28].replace("'", '')
				newGame.betting.spread = float( gameData[28] )
				gameData[29] = gameData[29][gameData[29].find('(')+1:gameData[29].find(')')]
				gameData[29] = gameData[29].replace("'", '')
				newGame.betting.overUnder = float( gameData[29] )
				newGame.betting.homeMoneyLine = int( gameData[30] )
				newGame.betting.awayMoneyLine = int( gameData[31] )
				gameArray.append( newGame )
			return gameArray
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return None

	def GetAllGameDataByWeek( self, week, season ):
		gameWeekData = []
		gameArray = []
		cypher = 'SELECT * FROM Games WHERE week={0} AND season_type="{1}"'.format( week, season )
		try:
			self.cursor.execute( cypher )
			gameWeekData = self.cursor.fetchall()
			for game in gameWeekData:
				gameString = '{0}'.format( game )
				gameString = gameString.lstrip( "(" )
				gameString = gameString.rstrip( ")" )
				gameData = gameString.split( "," )
				newGame = CFDB_Game()
				newGame.id = int( gameData[0] )
				newGame.season = int( gameData[1] )
				newGame.week = int( gameData[2] )
				newGame.season_type = gameData[3]
				newGame.start_data = gameData[4]
				if int(gameData[5]) != 0:
					newGame.start_time_tbd = True
				if int(gameData[6]) != 0:
					newGame.completed = True
				if int(gameData[7]) != 0:
					newGame.neutral_site = True
				if int(gameData[8]) != 0:
					newGame.conference_game = True
				newGame.attendance = int( gameData[9] )
				newGame.venue_id = int( gameData[10] )
				newGame.home_id = int( gameData[11] )
				newGame.home_team = gameData[12]
				newGame.home_conference = gameData[13]
				newGame.home_division = gameData[14]
				newGame.home_points = int( gameData[15] )
				newGame.home_points_q1 = int( gameData[16] )
				newGame.home_points_q2 = int( gameData[17] )
				newGame.home_points_q3 = int( gameData[18] )
				newGame.home_points_q4 = int( gameData[19] )
				newGame.home_points_ot = int( gameData[20] )
				gameData[21] = gameData[21][gameData[21].find('(')+1:gameData[21].find(')')]
				gameData[21] = gameData[21].replace("'", '')
				newGame.home_post_win_prob = float( gameData[21] )
				newGame.home_pregame_elo = int( gameData[22] )
				newGame.home_postgame_elo = int( gameData[23] )
				newGame.away_id = int( gameData[24] )
				newGame.away_team = gameData[25]
				newGame.away_conference = gameData[26]
				newGame.away_division = gameData[27]
				newGame.away_points = int( gameData[28] )
				newGame.away_points_q1 = int( gameData[29] )
				newGame.away_points_q2 = int( gameData[30] )
				newGame.away_points_q3 = int( gameData[31] )
				newGame.away_points_q4 = int( gameData[32] )
				newGame.away_points_ot = int( gameData[33] )
				gameData[34] = gameData[34][gameData[34].find('(')+1:gameData[34].find(')')]
				gameData[34] = gameData[34].replace("'", '')
				newGame.away_post_win_prob = float( gameData[34] )
				newGame.away_pregame_elo = int( gameData[35] )
				newGame.away_postgame_elo = int( gameData[36] )
				gameData[37] = gameData[37][gameData[37].find('(')+1:gameData[37].find(')')]
				gameData[37] = gameData[37].replace("'", '')
				newGame.excitement_index = float( gameData[37] )
				newGame.highlights = gameData[38]
				newGame.notes = gameData[39]
				gameArray.append(newGame)
			return gameArray
		except MySQLdb.Error as e:
			print('Error in {0}: {1}'.format(sys._getframe().f_code.co_name, e))
			return None

